@@ -27,7 +27,7 @@
  */
 
 	{ 0,	0,	sys_restart_syscall,	"restart_syscall"}, /* 0 */
-	{ 1,	TP,	sys_exit,		"exit"		}, /* 1 */
+	{ 1,	TP|SE,	sys_exit,		"exit"		}, /* 1 */
 	{ 0,	TP,	sys_fork,		"fork"		}, /* 2 */
 	{ 3,	TD,	sys_read,		"read"		}, /* 3 */
 	{ 3,	TD,	sys_write,		"write"		}, /* 4 */
@@ -37,7 +37,7 @@
 	{ 2,	TD|TF,	sys_creat,		"creat"		}, /* 8 */
 	{ 2,	TF,	sys_link,		"link"		}, /* 9 */
 	{ 1,	TF,	sys_unlink,		"unlink"	}, /* 10 */
-	{ 3,	TF|TP,	sys_execve,		"execve"	}, /* 11 */
+	{ 3,	TF|TP|SE|SI,	sys_execve,		"execve"	}, /* 11 */
 	{ 1,	TF,	sys_chdir,		"chdir"		}, /* 12 */
 	{ 1,	0,	sys_time,		"time"		}, /* 13 */
 	{ 3,	TF,	sys_mknod,		"mknod"		}, /* 14 */
@@ -71,7 +71,7 @@
 	{ 1,	TD,	sys_pipe,		"pipe"		}, /* 42 */
 	{ 1,	0,	sys_times,		"times"		}, /* 43 */
 	{ 0,	0,	sys_prof,		"prof"		}, /* 44 */
-	{ 1,	TM,	sys_brk,		"brk"		}, /* 45 */
+	{ 1,	TM|SI,	sys_brk,		"brk"		}, /* 45 */
 	{ 1,	0,	sys_setgid,		"setgid"	}, /* 46 */
 	{ 0,	NF,	sys_getgid,		"getgid"	}, /* 47 */
 	{ 3,	TS,	sys_signal,		"signal"	}, /* 48 */
@@ -116,8 +116,8 @@
 	{ 2,	TF,	sys_swapon,		"swapon"	}, /* 87 */
 	{ 4,	0,	sys_reboot,		"reboot"	}, /* 88 */
 	{ 3,	TD,	sys_readdir,		"readdir"	}, /* 89 */
-	{ 1,	TD|TM,	sys_old_mmap,		"old_mmap"	}, /* 90 */
-	{ 2,	TM,	sys_munmap,		"munmap"	}, /* 91 */
+	{ 1,	TD|TM|SI,	sys_old_mmap,		"old_mmap"	}, /* 90 */
+	{ 2,	TM|SI,	sys_munmap,		"munmap"	}, /* 91 */
 	{ 2,	TF,	sys_truncate,		"truncate"	}, /* 92 */
 	{ 2,	TD,	sys_ftruncate,		"ftruncate"	}, /* 93 */
 	{ 2,	TD,	sys_fchmod,		"fchmod"	}, /* 94 */
@@ -151,7 +151,7 @@
 	{ 1,	0,	sys_uname,		"uname"		}, /* 122 */
 	{ 3,	0,	sys_modify_ldt,		"modify_ldt"	}, /* 123 */
 	{ 1,	0,	sys_adjtimex,		"adjtimex"	}, /* 124 */
-	{ 3,	TM,	sys_mprotect,		"mprotect"	}, /* 125 */
+	{ 3,	TM|SI,	sys_mprotect,		"mprotect"	}, /* 125 */
 	{ 3,	TS,	sys_sigprocmask,	"sigprocmask"	}, /* 126 */
 	{ 2,	0,	sys_create_module,	"create_module"	}, /* 127 */
 	{ 3,	0,	sys_init_module,	"init_module"	}, /* 128 */
@@ -189,7 +189,7 @@
 	{ 1,	0,	sys_sched_get_priority_min,"sched_get_priority_min"}, /* 160 */
 	{ 2,	0,	sys_sched_rr_get_interval,"sched_rr_get_interval"}, /* 161 */
 	{ 2,	0,	sys_nanosleep,		"nanosleep"	}, /* 162 */
-	{ 5,	TM,	sys_mremap,		"mremap"	}, /* 163 */
+	{ 5,	TM|SI,	sys_mremap,		"mremap"	}, /* 163 */
 	{ 3,	0,	sys_setresuid,		"setresuid"	}, /* 164 */
 	{ 3,	0,	sys_getresuid,		"getresuid"	}, /* 165 */
 	{ 5,	0,	sys_vm86,		"vm86"		}, /* 166 */
@@ -219,7 +219,7 @@
 	{ 5,	0,	sys_putpmsg,		"putpmsg"	}, /* 189 */
 	{ 0,	TP,	sys_vfork,		"vfork"		}, /* 190 */
 	{ 2,	0,	sys_getrlimit,		"getrlimit"	}, /* 191 */
-	{ 6,	TD|TM,	sys_mmap_pgoff,		"mmap2"		}, /* 192 */
+	{ 6,	TD|TM|SI,	sys_mmap_pgoff,		"mmap2"		}, /* 192 */
 	{ 4,	TF,	sys_truncate64,		"truncate64"	}, /* 193 */
 	{ 4,	TD,	sys_ftruncate64,	"ftruncate64"	}, /* 194 */
 	{ 2,	TF,	sys_stat64,		"stat64"	}, /* 195 */
@@ -276,12 +276,12 @@
 	{ 5,	0,	sys_io_getevents,	"io_getevents"	}, /* 245 */
 	{ 3,	0,	sys_io_submit,		"io_submit"	}, /* 246 */
 	{ 3,	0,	sys_io_cancel,		"io_cancel"	}, /* 247 */
-	{ 1,	TP,	sys_exit,		"exit_group"	}, /* 248 */
+	{ 1,	TP|SE,	sys_exit,		"exit_group"	}, /* 248 */
 	{ 4,	0,	sys_lookup_dcookie,	"lookup_dcookie"}, /* 249 */
 	{ 1,	TD,	sys_epoll_create,	"epoll_create"	}, /* 250 */
 	{ 4,	TD,	sys_epoll_ctl,		"epoll_ctl"	}, /* 251 */
 	{ 4,	TD,	sys_epoll_wait,		"epoll_wait"	}, /* 252 */
-	{ 5,	TM,	sys_remap_file_pages,	"remap_file_pages"}, /* 253 */
+	{ 5,	TM|SI,	sys_remap_file_pages,	"remap_file_pages"}, /* 253 */
 	{ 5,	0,	NULL,			NULL		}, /* 254 */
 	{ 5,	0,	NULL,			NULL		}, /* 255 */
 	{ 1,	0,	sys_set_tid_address,	"set_tid_address"}, /* 256 */
@@ -333,8 +333,8 @@
 	{ 4,	TI,	sys_msgrcv,		"msgrcv"	}, /* 302 */
 	{ 4,	TI,	sys_msgget,		"msgget"	}, /* 303 */
 	{ 4,	TI,	sys_msgctl,		"msgctl"	}, /* 304 */
-	{ 4,	TI,	sys_shmat,		"shmat"		}, /* 305 */
-	{ 4,	TI,	sys_shmdt,		"shmdt"		}, /* 306 */
+	{ 4,	TI|TM|SI,	sys_shmat,		"shmat"		}, /* 305 */
+	{ 4,	TI|TM|SI,	sys_shmdt,		"shmdt"		}, /* 306 */
 	{ 4,	TI,	sys_shmget,		"shmget"	}, /* 307 */
 	{ 4,	TI,	sys_shmctl,		"shmctl"	}, /* 308 */
 	{ 5,	0,	sys_add_key,		"add_key"	}, /* 309 */
@@ -389,14 +389,14 @@
 	{ 3,	TD,	sys_dup3,		"dup3"		}, /* 358 */
 	{ 2,	TD,	sys_pipe2,		"pipe2"		}, /* 359 */
 	{ 1,	TD,	sys_inotify_init1,	"inotify_init1"	}, /* 360 */
-	{ 6,	TD,	sys_preadv,		"preadv"	}, /* 361 */
-	{ 6,	TD,	sys_pwritev,		"pwritev"	}, /* 362 */
+	{ 5,	TD,	sys_preadv,		"preadv"	}, /* 361 */
+	{ 5,	TD,	sys_pwritev,		"pwritev"	}, /* 362 */
 	{ 4,	TP|TS,	sys_rt_tgsigqueueinfo,	"rt_tgsigqueueinfo"}, /* 363 */
 	{ 5,	TD,	sys_perf_event_open,	"perf_event_open"}, /* 364 */
 	{ 5,	TN,	sys_recvmmsg,		"recvmmsg"	}, /* 365 */
 	{ 4,	TN,	sys_accept4,		"accept4"	}, /* 366 */
 	{ 2,	TD,	sys_fanotify_init,	"fanotify_init"	}, /* 367 */
-	{ 5,	TD|TF,	sys_fanotify_mark,	"fanotify_mark"	}, /* 368 */
+	{ 6,	TD|TF,	sys_fanotify_mark,	"fanotify_mark"	}, /* 368 */
 	{ 4,	0,	sys_prlimit64,		"prlimit64"	}, /* 369 */
 	{ 5,	TD|TF,	sys_name_to_handle_at,	"name_to_handle_at"}, /* 370 */
 	{ 3,	TD,	sys_open_by_handle_at,	"open_by_handle_at"}, /* 371 */
@@ -408,12 +408,12 @@
 	{ 6,	0,	sys_process_vm_writev,	"process_vm_writev"	}, /* 377 */
 	{ 5,	0,	sys_kcmp,		"kcmp"		}, /* 378 */
 	{ 3,	TD,	sys_finit_module,	"finit_module"	}, /* 379 */
+	{ 3,	0,	sys_sched_setattr,	"sched_setattr"	}, /* 380 */
+	{ 4,	0,	sys_sched_getattr,	"sched_getattr"	}, /* 381 */
+	{ 5,	TD|TF,	sys_renameat2,		"renameat2"	}, /* 382 */
 #ifdef __ARM_EABI__
-# define ARM_LAST_ORDINARY_SYSCALL 379
+# define ARM_LAST_ORDINARY_SYSCALL 382
 #else
-	{ 5,	0,	NULL,			NULL		}, /* 380 */
-	{ 5,	0,	NULL,			NULL		}, /* 381 */
-	{ 5,	0,	NULL,			NULL		}, /* 382 */
 	{ 5,	0,	NULL,			NULL		}, /* 383 */
 	{ 5,	0,	NULL,			NULL		}, /* 384 */
 	{ 5,	0,	NULL,			NULL		}, /* 385 */
@@ -478,8 +478,8 @@
 	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 438 */
 	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 439 */
 	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 440 */
-	{ 4,	TI,	sys_shmat,		"shmat"		}, /* 441 */
-	{ 4,	TI,	sys_shmdt,		"shmdt"		}, /* 442 */
+	{ 4,	TI|TM|SI,	sys_shmat,		"shmat"		}, /* 441 */
+	{ 4,	TI|TM|SI,	sys_shmdt,		"shmdt"		}, /* 442 */
 	{ 4,	TI,	sys_shmget,		"shmget"	}, /* 443 */
 	{ 4,	TI,	sys_shmctl,		"shmctl"	}, /* 444 */
 # define ARM_LAST_ORDINARY_SYSCALL 444
