@@ -3,7 +3,7 @@
  */
 
 	{ 0,	0,	sys_restart_syscall,	"restart_syscall"	}, /* 0 */
-	{ 1,	TP,	sys_exit,		"exit"			}, /* 1 */
+	{ 1,	TP|SE,	sys_exit,		"exit"			}, /* 1 */
 	{ 0,	TP,	sys_fork,		"fork"			}, /* 2 */
 	{ 3,	TD,	sys_read,		"read"			}, /* 3 */
 	{ 3,	TD,	sys_write,		"write"			}, /* 4 */
@@ -13,7 +13,7 @@
 	{ 2,	TD|TF,	sys_creat,		"creat"			}, /* 8 */
 	{ 2,	TF,	sys_link,		"link"			}, /* 9 */
 	{ 1,	TF,	sys_unlink,		"unlink"		}, /* 10 */
-	{ 3,	TF|TP,	sys_execve,		"execve"		}, /* 11 */
+	{ 3,	TF|TP|SE|SI,	sys_execve,		"execve"		}, /* 11 */
 	{ 1,	TF,	sys_chdir,		"chdir"			}, /* 12 */
 	{ 1,	0,	sys_time,		"time"			}, /* 13 */
 	{ 3,	TF,	sys_mknod,		"mknod"			}, /* 14 */
@@ -47,7 +47,7 @@
 	{ 1,	TD,	sys_pipe,		"pipe"			}, /* 42 */
 	{ 1,	0,	sys_times,		"times"			}, /* 43 */
 	{ 3,	TN,	sys_getsockname,	"getsockname"		}, /* 44 */
-	{ 1,	TM,	sys_brk,		"brk"			}, /* 45 */
+	{ 1,	TM|SI,	sys_brk,		"brk"			}, /* 45 */
 	{ 1,	0,	sys_setgid,		"setgid"		}, /* 46 */
 	{ 0,	NF,	sys_getgid,		"getgid"		}, /* 47 */
 	{ 2,	TS,	sys_signal,		"signal"		}, /* 48 */
@@ -91,9 +91,9 @@
 	{ 1,	TF,	sys_uselib,		"uselib"		}, /* 86 */
 	{ 2,	TF,	sys_swapon,		"swapon"		}, /* 87 */
 	{ 4,	0,	sys_reboot,		"reboot"		}, /* 88 */
-	{ 6,	TD|TM,	sys_mmap_4koff,		"mmap2"			}, /* 89 */
-	{ 6,	TD|TM,	sys_mmap,		"mmap"			}, /* 90 */
-	{ 2,	TM,	sys_munmap,		"munmap"		}, /* 91 */
+	{ 6,	TD|TM|SI,	sys_mmap_4koff,		"mmap2"			}, /* 89 */
+	{ 6,	TD|TM|SI,	sys_mmap,		"mmap"			}, /* 90 */
+	{ 2,	TM|SI,	sys_munmap,		"munmap"		}, /* 91 */
 	{ 2,	TF,	sys_truncate,		"truncate"		}, /* 92 */
 	{ 2,	TD,	sys_ftruncate,		"ftruncate"		}, /* 93 */
 	{ 2,	TD,	sys_fchmod,		"fchmod"		}, /* 94 */
@@ -127,7 +127,7 @@
 	{ 4,	TD|TN,	sys_sendfile,		"sendfile"		}, /* 122 */
 	{ 6,	TN,	sys_recvfrom,		"recvfrom"		}, /* 123 */
 	{ 1,	0,	sys_adjtimex,		"adjtimex"		}, /* 124 */
-	{ 3,	TM,	sys_mprotect,		"mprotect"		}, /* 125 */
+	{ 3,	TM|SI,	sys_mprotect,		"mprotect"		}, /* 125 */
 	{ 3,	TS,	sys_sigprocmask,	"sigprocmask"		}, /* 126 */
 	{ 2,	0,	sys_create_module,	"create_module"		}, /* 127 */
 	{ 4,	0,	sys_init_module,	"init_module"		}, /* 128 */
@@ -165,7 +165,7 @@
 	{ 1,	0,	sys_sched_get_priority_min,"sched_get_priority_min"}, /* 160 */
 	{ 2,	0,	sys_sched_rr_get_interval,"sched_rr_get_interval"}, /* 161 */
 	{ 2,	0,	sys_nanosleep,		"nanosleep"		}, /* 162 */
-	{ 5,	TM,	sys_mremap,		"mremap"		}, /* 163 */
+	{ 5,	TM|SI,	sys_mremap,		"mremap"		}, /* 163 */
 	{ 3,	0,	sys_setresuid,		"setresuid"		}, /* 164 */
 	{ 3,	0,	sys_setresuid,		"getresuid"		}, /* 165 */
 	{ 2,	TS,	sys_sigaltstack,	"sigaltstack"		}, /* 166 */
@@ -194,8 +194,8 @@
 	{ 4,	TI,	sys_msgrcv,		"msgrcv"		}, /* 189 */
 	{ 4,	TI,	sys_msgget,		"msgget"		}, /* 190 */
 	{ 4,	TI,	sys_msgctl,		"msgctl"		}, /* 191 */
-	{ 3,	TI,	sys_shmat,		"shmat"			}, /* 192 */
-	{ 1,	TI,	sys_shmdt,		"shmdt"			}, /* 193 */
+	{ 3,	TI|TM|SI,	sys_shmat,		"shmat"			}, /* 192 */
+	{ 1,	TI|TM|SI,	sys_shmdt,		"shmdt"			}, /* 193 */
 	{ 3,	TI,	sys_shmget,		"shmget"		}, /* 194 */
 	{ 3,	TI,	sys_shmctl,		"shmctl"		}, /* 195 */
 	{ 5,	0,	sys_getpmsg,		"getpmsg"		}, /* 196 */
@@ -224,12 +224,12 @@
 	{ 4,	0,	sys_io_cancel,		"io_cancel"		}, /* 219 */
 	{ 5,	0,	printargs,		"alloc_hugepages"	}, /* 220 */
 	{ 1,	0,	printargs,		"free_hugepages"	}, /* 221 */
-	{ 1,	TP,	sys_exit,		"exit_group"		}, /* 222 */
+	{ 1,	TP|SE,	sys_exit,		"exit_group"		}, /* 222 */
 	{ 4,	0,	sys_lookup_dcookie,	"lookup_dcookie"	}, /* 223 */
 	{ 1,	TD,	sys_epoll_create,	"epoll_create"		}, /* 224 */
 	{ 4,	TD,	sys_epoll_ctl,		"epoll_ctl"		}, /* 225 */
 	{ 4,	TD,	sys_epoll_wait,		"epoll_wait"		}, /* 226 */
-	{ 5,	TM,	printargs,		"remap_file_pages"	}, /* 227 */
+	{ 5,	TM|SI,	printargs,		"remap_file_pages"	}, /* 227 */
 	{ 5,	TI,	sys_semtimedop,		"semtimedop"		}, /* 228 */
 	{ 5,	0,	printargs,		"mq_open"		}, /* 229 */
 	{ 5,	0,	printargs,		"mq_unlink"		}, /* 230 */
@@ -237,7 +237,7 @@
 	{ 5,	0,	printargs,		"mq_timedreceive"		}, /* 232 */
 	{ 5,	0,	printargs,		"mq_notify"		}, /* 233 */
 	{ 5,	0,	printargs,		"mq_getsetattr"		}, /* 234 */
-	{ 4,	0,	printargs,		"waitid"		}, /* 235 */
+	{ 5,	TP,	sys_waitid,		"waitid"		}, /* 235 */
 	{ 6,	TD,	sys_fadvise64_64,	"fadvise64_64"		}, /* 236 */
 	{ 5,	0,	sys_set_tid_address,	"set_tid_address"	}, /* 237 */
 	{ 5,	TF,	sys_setxattr,		"setxattr"		}, /* 238 */
@@ -325,7 +325,7 @@
 	{ 4,	TN,	sys_accept4,		"accept4"		}, /* 320 */
 	{ 4,	0,	sys_prlimit64,		"prlimit64"		}, /* 321 */
 	{ 2,	TD,	sys_fanotify_init,	"fanotify_init"		}, /* 322 */
-	{ 5,	TD|TF,	sys_fanotify_mark,	"fanotify_mark"		}, /* 323 */
+	{ 6,	TD|TF,	sys_fanotify_mark,	"fanotify_mark"		}, /* 323 */
 	{ 2,	0,	sys_clock_adjtime,	"clock_adjtime"		}, /* 324 */
 	{ 5,	TD|TF,	sys_name_to_handle_at,	"name_to_handle_at"	}, /* 325 */
 	{ 3,	TD,	sys_open_by_handle_at,	"open_by_handle_at"	}, /* 326 */
@@ -336,3 +336,7 @@
 	{ 6,	0,	sys_process_vm_writev,	"process_vm_writev"	}, /* 331 */
 	{ 5,	0,	sys_kcmp,		"kcmp"			}, /* 332 */
 	{ 3,	TD,	sys_finit_module,	"finit_module"		}, /* 333 */
+	{ 3,	0,	sys_sched_setattr,	"sched_setattr"		}, /* 334 */
+	{ 4,	0,	sys_sched_getattr,	"sched_getattr"		}, /* 335 */
+	{ 2,	TF,	sys_utimes,		"utimes"		}, /* 336 */
+	{ 5,	TD|TF,	sys_renameat2,		"renameat2"		}, /* 337 */
