@@ -27,7 +27,7 @@
  */
 
 	{ 0,	0,	sys_restart_syscall,	"restart_syscall"	}, /* 0 */
-	{ 1,	TP,	sys_exit,		"exit"			}, /* 1 */
+	{ 1,	TP|SE,	sys_exit,		"exit"			}, /* 1 */
 	{ 0,	TP,	sys_fork,		"fork"			}, /* 2 */
 	{ 3,	TD,	sys_read,		"read"			}, /* 3 */
 	{ 3,	TD,	sys_write,		"write"			}, /* 4 */
@@ -37,15 +37,15 @@
 	{ 2,	TD|TF,	sys_creat,		"creat"			}, /* 8 */
 	{ 2,	TF,	sys_link,		"link"			}, /* 9 */
 	{ 1,	TF,	sys_unlink,		"unlink"		}, /* 10 */
-	{ 3,	TF|TP,	sys_execve,		"execve"		}, /* 11 */
+	{ 3,	TF|TP|SE|SI,	sys_execve,		"execve"		}, /* 11 */
 	{ 1,	TF,	sys_chdir,		"chdir"			}, /* 12 */
 	{ 1,	0,	sys_time,		"time"			}, /* 13 */
 	{ 3,	TF,	sys_mknod,		"mknod"			}, /* 14 */
 	{ 2,	TF,	sys_chmod,		"chmod"			}, /* 15 */
 	{ 3,	TF,	sys_chown,		"lchown"		}, /* 16 */
-	{ 0,	0,	sys_break,		"break"			}, /* 17 */
+	{ 0,	TM,	sys_break,		"break"			}, /* 17 */
 	{ 2,	TF,	sys_oldstat,		"oldstat"		}, /* 18 */
-	{ 3,	TF,	sys_lseek,		"lseek"			}, /* 19 */
+	{ 3,	TD,	sys_lseek,		"lseek"			}, /* 19 */
 	{ 0,	0,	sys_getpid,		"getpid"		}, /* 20 */
 	{ 5,	TF,	sys_mount,		"mount"			}, /* 21 */
 	{ 1,	TF,	sys_umount,		"oldumount"		}, /* 22 */
@@ -71,7 +71,7 @@
 	{ 1,	TD,	sys_pipe,		"pipe"			}, /* 42 */
 	{ 1,	0,	sys_times,		"times"			}, /* 43 */
 	{ 0,	0,	sys_prof,		"prof"			}, /* 44 */
-	{ 1,	0,	sys_brk,		"brk"			}, /* 45 */
+	{ 1,	TM|SI,	sys_brk,		"brk"			}, /* 45 */
 	{ 1,	0,	sys_setgid,		"setgid"		}, /* 46 */
 	{ 0,	NF,	sys_getgid,		"getgid"		}, /* 47 */
 	{ 3,	TS,	sys_signal,		"signal"		}, /* 48 */
@@ -116,8 +116,8 @@
 	{ 2,	TF,	sys_swapon,		"swapon"		}, /* 87 */
 	{ 4,	0,	sys_reboot,		"reboot"		}, /* 88 */
 	{ 3,	TD,	sys_readdir,		"readdir"		}, /* 89 */
-	{ 6,	TD,	sys_mmap,		"mmap"			}, /* 90 */
-	{ 2,	0,	sys_munmap,		"munmap"		}, /* 91 */
+	{ 6,	TD|TM|SI,	sys_mmap,		"mmap"			}, /* 90 */
+	{ 2,	TM|SI,	sys_munmap,		"munmap"		}, /* 91 */
 	{ 2,	TF,	sys_truncate,		"truncate"		}, /* 92 */
 	{ 2,	TD,	sys_ftruncate,		"ftruncate"		}, /* 93 */
 	{ 2,	TD,	sys_fchmod,		"fchmod"		}, /* 94 */
@@ -151,35 +151,35 @@
 	{ 1,	0,	sys_uname,		"uname"			}, /* 122 */
 	{ 5,	0,	printargs,		"modify_ldt"		}, /* 123 */
 	{ 1,	0,	sys_adjtimex,		"adjtimex"		}, /* 124 */
-	{ 3,	0,	sys_mprotect,		"mprotect"		}, /* 125 */
+	{ 3,	TM|SI,	sys_mprotect,		"mprotect"		}, /* 125 */
 	{ 3,	TS,	sys_sigprocmask,	"sigprocmask"		}, /* 126 */
 	{ 2,	0,	sys_create_module,	"create_module"		}, /* 127 */
 	{ 3,	0,	sys_init_module,	"init_module"		}, /* 128 */
 	{ 2,	0,	sys_delete_module,	"delete_module"		}, /* 129 */
 	{ 1,	0,	sys_get_kernel_syms,	"get_kernel_syms"	}, /* 130 */
-	{ 4,	0,	sys_quotactl,		"quotactl"		}, /* 131 */
+	{ 4,	TF,	sys_quotactl,		"quotactl"		}, /* 131 */
 	{ 1,	0,	sys_getpgid,		"getpgid"		}, /* 132 */
-	{ 1,	TF,	sys_fchdir,		"fchdir"		}, /* 133 */
+	{ 1,	TD,	sys_fchdir,		"fchdir"		}, /* 133 */
 	{ 0,	0,	sys_bdflush,		"bdflush"		}, /* 134 */
 	{ 3,	0,	sys_sysfs,		"sysfs"			}, /* 135 */
 	{ 1,	0,	sys_personality,	"personality"		}, /* 136 */
 	{ 5,	0,	sys_afs_syscall,	"afs_syscall"		}, /* 137 */
 	{ 1,	NF,	sys_setfsuid,		"setfsuid"		}, /* 138 */
 	{ 1,	NF,	sys_setfsgid,		"setfsgid"		}, /* 139 */
-	{ 5,	TF,	sys_llseek,		"_llseek"		}, /* 140 */
+	{ 5,	TD,	sys_llseek,		"_llseek"		}, /* 140 */
 	{ 3,	TD,	sys_getdents,		"getdents"		}, /* 141 */
 	{ 5,	TD,	sys_select,		"select"		}, /* 142 */
 	{ 2,	TD,	sys_flock,		"flock"			}, /* 143 */
-	{ 3,	0,	sys_msync,		"msync"			}, /* 144 */
+	{ 3,	TM,	sys_msync,		"msync"			}, /* 144 */
 	{ 3,	TD,	sys_readv,		"readv"			}, /* 145 */
 	{ 3,	TD,	sys_writev,		"writev"		}, /* 146 */
 	{ 1,	0,	sys_getsid,		"getsid"		}, /* 147 */
 	{ 1,	TD,	sys_fdatasync,		"fdatasync"		}, /* 148 */
 	{ 1,	0,	sys_sysctl,		"_sysctl"		}, /* 149 */
-	{ 2,	0,	sys_mlock,		"mlock"			}, /* 150 */
-	{ 2,	0,	sys_munlock,		"munlock"		}, /* 151 */
-	{ 1,	0,	sys_mlockall,		"mlockall"		}, /* 152 */
-	{ 0,	0,	sys_munlockall,		"munlockall"		}, /* 153 */
+	{ 2,	TM,	sys_mlock,		"mlock"			}, /* 150 */
+	{ 2,	TM,	sys_munlock,		"munlock"		}, /* 151 */
+	{ 1,	TM,	sys_mlockall,		"mlockall"		}, /* 152 */
+	{ 0,	TM,	sys_munlockall,		"munlockall"		}, /* 153 */
 	{ 2,	0,	sys_sched_setparam,	"sched_setparam"	}, /* 154 */
 	{ 2,	0,	sys_sched_getparam,	"sched_getparam"	}, /* 155 */
 	{ 3,	0,	sys_sched_setscheduler,	"sched_setscheduler"	}, /* 156 */
@@ -189,7 +189,7 @@
 	{ 1,	0,	sys_sched_get_priority_min,"sched_get_priority_min"}, /* 160 */
 	{ 2,	0,	sys_sched_rr_get_interval,"sched_rr_get_interval"}, /* 161 */
 	{ 2,	0,	sys_nanosleep,		"nanosleep"		}, /* 162 */
-	{ 5,	0,	sys_mremap,		"mremap"		}, /* 163 */
+	{ 5,	TM|SI,	sys_mremap,		"mremap"		}, /* 163 */
 	{ 3,	0,	sys_setresuid,		"setresuid"		}, /* 164 */
 	{ 3,	0,	sys_getresuid,		"getresuid"		}, /* 165 */
 	{ 5,	0,	sys_query_module,	"query_module"		}, /* 166 */
@@ -218,7 +218,7 @@
 	{ 0,	TP,	sys_vfork,		"vfork"			}, /* 189 */
 	{ 2,	0,	sys_getrlimit,		"getrlimit"		}, /* 190 */
 	{ 5,	TD,	sys_readahead,		"readahead"		}, /* 190 */
-	{ 6,	TD,	sys_mmap,		"mmap2"			}, /* 192 */
+	{ 6,	TD|TM|SI,	sys_mmap_4koff,		"mmap2"			}, /* 192 */
 	{ 4,	TF,	sys_truncate64,		"truncate64"		}, /* 193 */
 	{ 4,	TD,	sys_ftruncate64,	"ftruncate64"		}, /* 194 */
 	{ 2,	TF,	sys_stat64,		"stat64"		}, /* 195 */
@@ -231,8 +231,8 @@
 	{ 3,	TD,	sys_getdents64,		"getdents64"		}, /* 202 */
 	{ 2,	TF,	sys_pivotroot,		"pivot_root"		}, /* 203 */
 	{ 3,	TD,	sys_fcntl,		"fcntl64"		}, /* 204 */
-	{ 3,	0,	sys_madvise,		"madvise"		}, /* 205 */
-	{ 3,	0,	sys_mincore,		"mincore"		}, /* 206 */
+	{ 3,	TM,	sys_madvise,		"madvise"		}, /* 205 */
+	{ 3,	TM,	sys_mincore,		"mincore"		}, /* 206 */
 	{ 0,	0,	sys_gettid,		"gettid"		}, /* 207 */
 	{ 2,	TS,	sys_kill,		"tkill"			}, /* 208 */
 	{ 5,	TF,	sys_setxattr,		"setxattr"		}, /* 209 */
@@ -260,12 +260,12 @@
 	{ 3,	0,	sys_io_cancel,		"io_cancel"		}, /* 231 */
 	{ 1,	0,	sys_set_tid_address,	"set_tid_address"	}, /* 232 */
 	{ 6,	TD,	sys_fadvise64,		"fadvise64"		}, /* 233 */
-	{ 1,	TP,	sys_exit,		"exit_group"		}, /* 234 */
+	{ 1,	TP|SE,	sys_exit,		"exit_group"		}, /* 234 */
 	{ 4,	0,	sys_lookup_dcookie,	"lookup_dcookie"	}, /* 235 */
 	{ 1,	TD,	sys_epoll_create,	"epoll_create"		}, /* 236 */
 	{ 4,	TD,	sys_epoll_ctl,		"epoll_ctl"		}, /* 237 */
 	{ 4,	TD,	sys_epoll_wait,		"epoll_wait"		}, /* 238 */
-	{ 5,	0,	sys_remap_file_pages,	"remap_file_pages"	}, /* 239 */
+	{ 5,	TM|SI,	sys_remap_file_pages,	"remap_file_pages"	}, /* 239 */
 	{ 3,	0,	sys_timer_create,	"timer_create"		}, /* 240 */
 	{ 4,	0,	sys_timer_settime,	"timer_settime"		}, /* 241 */
 	{ 2,	0,	sys_timer_gettime,	"timer_gettime"		}, /* 242 */
@@ -284,10 +284,10 @@
 	{ 1,	0,	printargs,		"rtas"			}, /* 255 */
 	{ 5,	0,	printargs,		"debug_setcontext"	}, /* 256 */
 	{ 5,	0,	sys_vserver,		"vserver"		}, /* 257 */
-	{ 5,	0,	sys_migrate_pages,	"migrate_pages"		}, /* 258 */
-	{ 6,	0,	sys_mbind,		"mbind"			}, /* 259 */
-	{ 5,	0,	sys_get_mempolicy,	"get_mempolicy"		}, /* 260 */
-	{ 3,	0,	sys_set_mempolicy,	"set_mempolicy"		}, /* 261 */
+	{ 5,	TM,	sys_migrate_pages,	"migrate_pages"		}, /* 258 */
+	{ 6,	TM,	sys_mbind,		"mbind"			}, /* 259 */
+	{ 5,	TM,	sys_get_mempolicy,	"get_mempolicy"		}, /* 260 */
+	{ 3,	TM,	sys_set_mempolicy,	"set_mempolicy"		}, /* 261 */
 	{ 4,	0,	sys_mq_open,		"mq_open"		}, /* 262 */
 	{ 1,	0,	sys_mq_unlink,		"mq_unlink"		}, /* 263 */
 	{ 5,	0,	sys_mq_timedsend,	"mq_timedsend"		}, /* 264 */
@@ -327,14 +327,14 @@
 	{ 3,	TD|TF,	sys_faccessat,		"faccessat"		}, /* 298 */
 	{ 3,	0,	sys_get_robust_list,	"get_robust_list"	}, /* 299 */
 	{ 2,	0,	sys_set_robust_list,	"set_robust_list"	}, /* 300 */
-	{ 6,	0,	sys_move_pages,		"move_pages"		}, /* 301 */
+	{ 6,	TM,	sys_move_pages,		"move_pages"		}, /* 301 */
 	{ 3,	0,	sys_getcpu,		"getcpu"		}, /* 302 */
 	{ 6,	TD,	sys_epoll_pwait,	"epoll_pwait"		}, /* 303 */
 	{ 4,	TD|TF,	sys_utimensat,		"utimensat"		}, /* 304 */
 	{ 3,	TD|TS,	sys_signalfd,		"signalfd"		}, /* 305 */
-	{ 4,	TD,	sys_timerfd_create,	"timerfd_create"	}, /* 306 */
+	{ 2,	TD,	sys_timerfd_create,	"timerfd_create"	}, /* 306 */
 	{ 1,	TD,	sys_eventfd,		"eventfd"		}, /* 307 */
-	{ 4,	TD,	sys_sync_file_range,	"sync_file_range"	}, /* 308 */
+	{ 6,	TD,	sys_sync_file_range2,	"sync_file_range2"	}, /* 308 */
 	{ 6,	TD,	sys_fallocate,		"fallocate"		}, /* 309 */
 	{ 3,	0,	sys_subpage_prot,	"subpage_prot"		}, /* 310 */
 	{ 4,	TD,	sys_timerfd_settime,	"timerfd_settime"	}, /* 311 */
@@ -350,7 +350,7 @@
 	{ 5,	TD,	sys_pwritev,		"pwritev"		}, /* 321 */
 	{ 4,	TP|TS,	sys_rt_tgsigqueueinfo,	"rt_tgsigqueueinfo"	}, /* 322 */
 	{ 2,	TD,	sys_fanotify_init,	"fanotify_init"		}, /* 323 */
-	{ 5,	TD|TF,	sys_fanotify_mark,	"fanotify_mark"		}, /* 324 */
+	{ 6,	TD|TF,	sys_fanotify_mark,	"fanotify_mark"		}, /* 324 */
 	{ 4,	0,	sys_prlimit64,		"prlimit64"		}, /* 325 */
 	{ 3,	TN,	sys_socket,		"socket"		}, /* 326 */
 	{ 3,	TN,	sys_bind,		"bind"			}, /* 327 */
@@ -368,7 +368,7 @@
 	{ 5,	TN,	sys_setsockopt,		"setsockopt"		}, /* 339 */
 	{ 5,	TN,	sys_getsockopt,		"getsockopt"		}, /* 340 */
 	{ 3,	TN,	sys_sendmsg,		"sendmsg"		}, /* 341 */
-	{ 5,	TN,	sys_recvmsg,		"recvmsg"		}, /* 342 */
+	{ 3,	TN,	sys_recvmsg,		"recvmsg"		}, /* 342 */
 	{ 5,	TN,	sys_recvmmsg,		"recvmmsg"		}, /* 343 */
 	{ 4,	TN,	sys_accept4,		"accept4"		}, /* 344 */
 	{ 5,	TD|TF,	sys_name_to_handle_at,	"name_to_handle_at"	}, /* 345 */
@@ -379,11 +379,11 @@
 	{ 2,	TD,	sys_setns,		"setns"			}, /* 350 */
 	{ 6,	0,	sys_process_vm_readv,	"process_vm_readv"	}, /* 351 */
 	{ 6,	0,	sys_process_vm_writev,	"process_vm_writev"	}, /* 352 */
-	{ 5,	0,	NULL,			NULL			}, /* 353 */
-	{ 5,	0,	NULL,			NULL			}, /* 354 */
-	{ 5,	0,	NULL,			NULL			}, /* 355 */
-	{ 5,	0,	NULL,			NULL			}, /* 356 */
-	{ 5,	0,	NULL,			NULL			}, /* 357 */
+	{ 3,	TD,	sys_finit_module,	"finit_module"		}, /* 353 */
+	{ 5,	0,	sys_kcmp,		"kcmp"			}, /* 354 */
+	{ 3,	0,	sys_sched_setattr,	"sched_setattr"		}, /* 355 */
+	{ 4,	0,	sys_sched_getattr,	"sched_getattr"		}, /* 356 */
+	{ 5,	TD|TF,	sys_renameat2,		"renameat2"		}, /* 357 */
 	{ 5,	0,	NULL,			NULL			}, /* 358 */
 	{ 5,	0,	NULL,			NULL			}, /* 359 */
 	{ 5,	0,	NULL,			NULL			}, /* 360 */
@@ -426,10 +426,8 @@
 	{ 5,	0,	NULL,			NULL			}, /* 397 */
 	{ 5,	0,	NULL,			NULL			}, /* 398 */
 	{ 5,	0,	NULL,			NULL			}, /* 399 */
-
-#if SYS_socket_subcall != 400
- #error fix me
-#endif
+#define SYS_socket_subcall	400
+#include "subcall.h"
 	{ 6,	0,	printargs,		"socket_subcall"}, /* 400 */
 	{ 3,	TN,	sys_socket,		"socket"	}, /* 401 */
 	{ 3,	TN,	sys_bind,		"bind"		}, /* 402 */
@@ -447,7 +445,7 @@
 	{ 5,	TN,	sys_setsockopt,		"setsockopt"	}, /* 414 */
 	{ 5,	TN,	sys_getsockopt,		"getsockopt"	}, /* 415 */
 	{ 3,	TN,	sys_sendmsg,		"sendmsg"	}, /* 416 */
-	{ 5,	TN,	sys_recvmsg,		"recvmsg"	}, /* 417 */
+	{ 3,	TN,	sys_recvmsg,		"recvmsg"	}, /* 417 */
 	{ 4,	TN,	sys_accept4,		"accept4"	}, /* 418 */
 	{ 5,	TN,	sys_recvmmsg,		"recvmmsg"	}, /* 419 */
 
@@ -475,8 +473,8 @@
 	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 438 */
 	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 439 */
 	{ 4,	0,	printargs,		"ipc_subcall"	}, /* 440 */
-	{ 4,	TI,	sys_shmat,		"shmat"		}, /* 441 */
-	{ 4,	TI,	sys_shmdt,		"shmdt"		}, /* 442 */
+	{ 4,	TI|TM|SI,	sys_shmat,		"shmat"		}, /* 441 */
+	{ 4,	TI|TM|SI,	sys_shmdt,		"shmdt"		}, /* 442 */
 	{ 4,	TI,	sys_shmget,		"shmget"	}, /* 443 */
 	{ 4,	TI,	sys_shmctl,		"shmctl"	}, /* 444 */
 	{ 5,	0,	NULL,			NULL		}, /* 445 */
