@@ -27,7 +27,7 @@
  */
 
 	{ 0,	0,	sys_setup,		"setup"		}, /* 0 */
-	{ 1,	TP,	sys_exit,		"_exit"		}, /* 1 */
+	{ 1,	TP|SE,	sys_exit,		"_exit"		}, /* 1 */
 	{ 0,	TP,	sys_fork,		"fork"		}, /* 2 */
 	{ 3,	TD,	sys_read,		"read"		}, /* 3 */
 	{ 3,	TD,	sys_write,		"write"		}, /* 4 */
@@ -37,7 +37,7 @@
 	{ 2,	TD|TF,	sys_creat,		"creat"		}, /* 8 */
 	{ 2,	TF,	sys_link,		"link"		}, /* 9 */
 	{ 1,	TF,	sys_unlink,		"unlink"	}, /* 10 */
-	{ 3,	TF|TP,	sys_execve,		"execve"	}, /* 11 */
+	{ 3,	TF|TP|SE|SI,	sys_execve,		"execve"	}, /* 11 */
 	{ 1,	TF,	sys_chdir,		"chdir"		}, /* 12 */
 	{ 1,	0,	sys_time,		"time"		}, /* 13 */
 	{ 3,	TF,	sys_mknod,		"mknod"		}, /* 14 */
@@ -71,7 +71,7 @@
 	{ 1,	TD,	sys_pipe,		"pipe"		}, /* 42 */
 	{ 1,	0,	sys_times,		"times"		}, /* 43 */
 	{ 0,	0,	sys_prof,		"prof"		}, /* 44 */
-	{ 1,	TM,	sys_brk,		"brk"		}, /* 45 */
+	{ 1,	TM|SI,	sys_brk,		"brk"		}, /* 45 */
 	{ 1,	0,	sys_setgid,		"setgid"	}, /* 46 */
 	{ 0,	NF,	sys_getgid,		"getgid"	}, /* 47 */
 	{ 3,	TS,	sys_signal,		"signal"	}, /* 48 */
@@ -116,8 +116,8 @@
 	{ 2,	TF,	sys_swapon,		"swapon"	}, /* 87 */
 	{ 4,	0,	sys_reboot,		"reboot"	}, /* 88 */
 	{ 3,	TD,	sys_readdir,		"readdir"	}, /* 89 */
-	{ 6,	TD|TM,	sys_mmap,		"old_mmap"	}, /* 90 */
-	{ 2,	TM,	sys_munmap,		"munmap"	}, /* 91 */
+	{ 6,	TD|TM|SI,	sys_mmap,		"old_mmap"	}, /* 90 */
+	{ 2,	TM|SI,	sys_munmap,		"munmap"	}, /* 91 */
 	{ 2,	TF,	sys_truncate,		"truncate"	}, /* 92 */
 	{ 2,	TD,	sys_ftruncate,		"ftruncate"	}, /* 93 */
 	{ 2,	TD,	sys_fchmod,		"fchmod"	}, /* 94 */
@@ -151,7 +151,7 @@
 	{ 1,	0,	sys_uname,		"uname"		}, /* 122 */
 	{ 3,	0,	printargs,		"cacheflush"	}, /* 123 */
 	{ 1,	0,	sys_adjtimex,		"adjtimex"	}, /* 124 */
-	{ 3,	TM,	sys_mprotect,		"mprotect"	}, /* 125 */
+	{ 3,	TM|SI,	sys_mprotect,		"mprotect"	}, /* 125 */
 	{ 3,	TS,	sys_sigprocmask,	"sigprocmask"	}, /* 126 */
 	{ 2,	0,	sys_create_module,	"create_module"	}, /* 127 */
 	{ 3,	0,	sys_init_module,	"init_module"	}, /* 128 */
@@ -189,7 +189,7 @@
 	{ 1,	0,	sys_sched_get_priority_min,"sched_get_priority_min"}, /* 160 */
 	{ 2,	0,	sys_sched_rr_get_interval,"sched_rr_get_interval"}, /* 161 */
 	{ 2,	0,	sys_nanosleep,		"nanosleep"	}, /* 162 */
-	{ 5,	TM,	sys_mremap,		"mremap"	}, /* 163 */
+	{ 5,	TM|SI,	sys_mremap,		"mremap"	}, /* 163 */
 	{ 3,	0,	sys_setresuid,		"setresuid"	}, /* 164 */
 	{ 3,	0,	sys_getresuid,		"getresuid"	}, /* 165 */
 	{ 5,	0,	NULL,			NULL		}, /* 166 */
@@ -218,7 +218,7 @@
 	{ 5,	0,	NULL,			NULL		}, /* 189 */
 	{ 0,	TP,	sys_vfork,		"vfork"		}, /* 190 */
 	{ 2,	0,	printargs,		"getrlimit"	}, /* 191 */
-	{ 6,	TD|TM,	sys_mmap_4koff,		"mmap2"		}, /* 192 */
+	{ 6,	TD|TM|SI,	sys_mmap_4koff,		"mmap2"		}, /* 192 */
 	{ 2,	TF,	sys_truncate,		"truncate64"	}, /* 193 */
 	{ 2,	TD,	sys_ftruncate,		"ftruncate64"	}, /* 194 */
 	{ 2,	TF,	sys_stat64,		"stat64"	}, /* 195 */
@@ -270,8 +270,8 @@
 	{ 4,	TI,	sys_msgrcv,		"msgrcv"	}, /* 241 */
 	{ 4,	TI,	sys_msgget,		"msgget"	}, /* 242 */
 	{ 4,	TI,	sys_msgctl,		"msgctl"	}, /* 243 */
-	{ 4,	TI,	sys_shmat,		"shmat"		}, /* 244 */
-	{ 4,	TI,	sys_shmdt,		"shmdt"		}, /* 245 */
+	{ 4,	TI|TM|SI,	sys_shmat,		"shmat"		}, /* 244 */
+	{ 4,	TI|TM|SI,	sys_shmdt,		"shmdt"		}, /* 245 */
 	{ 4,	TI,	sys_shmget,		"shmget"	}, /* 246 */
 	{ 4,	TI,	sys_shmctl,		"shmctl"	}, /* 247 */
 	{ 3,	TD,	sys_getdents64,		"getdents64"	}, /* 248 */
@@ -306,12 +306,12 @@
 	{ 3,	0,	sys_io_cancel,		"io_cancel"	}, /* 277 */
 	{ 4,	TD,	sys_fadvise64,		"fadvise64"	}, /* 278 */
 	{ 5,	0,	NULL,			NULL		}, /* 279 */
-	{ 1,	TP,	sys_exit,		"exit_group"	}, /* 280 */
+	{ 1,	TP|SE,	sys_exit,		"exit_group"	}, /* 280 */
 	{ 3,	0,	sys_lookup_dcookie,	"lookup_dcookie"}, /* 281 */
 	{ 1,	TD,	sys_epoll_create,	"epoll_create"	}, /* 282 */
 	{ 4,	TD,	sys_epoll_ctl,		"epoll_ctl"	}, /* 283 */
 	{ 4,	TD,	sys_epoll_wait,		"epoll_wait"	}, /* 284 */
-	{ 5,	TM,	sys_remap_file_pages,	"remap_file_pages"}, /* 285 */
+	{ 5,	TM|SI,	sys_remap_file_pages,	"remap_file_pages"}, /* 285 */
 	{ 1,	0,	sys_set_tid_address,	"set_tid_address"}, /* 286 */
 	{ 3,	0,	sys_timer_create,	"timer_create"	}, /* 287 */
 	{ 4,	0,	sys_timer_settime,	"timer_settime"	}, /* 288 */
