@@ -33,6 +33,7 @@
 int sys_accept();
 int sys_accept4();
 int sys_access();
+int sys_add_key();
 int sys_adjtimex();
 int sys_arch_prctl();
 int sys_bind();
@@ -51,6 +52,8 @@ int sys_close();
 int sys_connect();
 int sys_creat();
 int sys_create_module();
+int sys_delete_module();
+int sys_dup();
 int sys_dup2();
 int sys_dup3();
 int sys_epoll_create();
@@ -66,12 +69,15 @@ int sys_faccessat();
 int sys_fadvise64();
 int sys_fadvise64_64();
 int sys_fallocate();
+int sys_fanotify_init();
+int sys_fanotify_mark();
 int sys_fchmod();
 int sys_fchmodat();
 int sys_fchown();
 int sys_fchownat();
 int sys_fcntl();
 int sys_fgetxattr();
+int sys_finit_module();
 int sys_flistxattr();
 int sys_flock();
 int sys_fork();
@@ -118,7 +124,11 @@ int sys_io_getevents();
 int sys_io_setup();
 int sys_io_submit();
 int sys_ioctl();
+int sys_ioprio_get();
+int sys_ioprio_set();
 int sys_ipc();
+int sys_keyctl();
+int sys_kexec_load();
 int sys_kill();
 int sys_link();
 int sys_linkat();
@@ -197,6 +207,8 @@ int sys_recvmsg();
 int sys_remap_file_pages();
 int sys_removexattr();
 int sys_renameat();
+int sys_renameat2();
+int sys_request_key();
 int sys_restart_syscall();
 int sys_rt_sigaction();
 int sys_rt_sigpending();
@@ -232,6 +244,7 @@ int sys_setgroups();
 int sys_setgroups32();
 int sys_sethostname();
 int sys_setitimer();
+int sys_setns();
 int sys_setpriority();
 int sys_setresuid();
 int sys_setreuid();
@@ -267,6 +280,8 @@ int sys_statfs64();
 int sys_stime();
 int sys_swapon();
 int sys_symlinkat();
+int sys_sync_file_range();
+int sys_sync_file_range2();
 int sys_sysctl();
 int sys_sysinfo();
 int sys_syslog();
@@ -291,7 +306,6 @@ int sys_unshare();
 int sys_utime();
 int sys_utimensat();
 int sys_utimes();
-int sys_vfork();
 int sys_vmsplice();
 int sys_wait4();
 int sys_waitid();
